Learn R Programming

HWEintrinsic (version 1.2.3)

GuoThompson8: Guo and Thompson (1992) Eight Alleles Simulated Data

Description

A sample of size \(n = 30\) of genotype frequencies from a population of \(r = 8\) alleles simulated under the Hardy-Weinberg equilibrium when the underlying gene frequencies are (.2, .2, .2, .2, .05, .05, .05, .05); see Guo and Thompson (1992), Example 2.

Usage

data(GuoThompson8)

Arguments

Format

An object of class HWEdata.

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

Examples

Run this code
# Example 1 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #


data(GuoThompson8)
plot(GuoThompson8)
n <- sum(GuoThompson8@data.vec, na.rm = TRUE)
out <- hwe.ibf.mc(GuoThompson8, t = n/2, M = 100000, verbose = TRUE)
summary(out, plot = TRUE)
}

# Example 2 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #

M <- 300000
f <- seq(.1, 1, .05)
n <- sum(GuoThompson8@data.vec, na.rm = TRUE)
out <- hwe.ibf.plot(y = GuoThompson8, t.vec = round(f*n), M = M)
}

Run the code above in your browser using DataLab