Learn R Programming

HWEintrinsic (version 1.2.3)

HWEdata-class: Class "HWEdata". Data specification for the Hardy-Weinberg Testing Problem Using the Intrinsic Prior Approach.

Description

This class encapsulates the data specification for a Bayesian objective analysis via intrinsic priors of the Hardy-Weinberg Testing Problem as described in Consonni et al. (2011).

Arguments

Objects from the Class

Objects can be created by calls of the form new("HWEdata", data), where data are the data in vector form.

Slots

data.mat:

Object of class "matrix"; data in matrix form.

size:

Object of class "numeric"; number of alleles included in the data.

data.vec:

Object of class "numeric"; data in vector form.

Methods

%\item{initialize}{\code{signature(.Object = "HWEdata")}: Class initialization.}
plot

signature(x = "HWEdata", y = "missing"): Provides a pictorial representation for a sample of genotype counts.

summary

signature(object = "HWEdata"): Extracts the contents of an HWEdata object.

Author

Sergio Venturini sergio.venturini@unicatt.it

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

See Also

hwe.ibf, hwe.ibf.mc, hwe.ibf.plot.

Examples

Run this code
data.tmp <- c(3, 9, 8)
dataset <- new("HWEdata", data = data.tmp)

Run the code above in your browser using DataLab