Learn R Programming

HWEintrinsic (version 1.2.3)

cip.2: Graph of the Conditional Intrinsic Prior for a Two Alleles Dataset

Description

This function produces the 3D plot for the conditional intrinsic prior based on a sample of two alleles data as described in Consonni et al. (2011).

Usage

cip.2(t, p, k = 30)

Value

No object is returned by this function.

Arguments

t

training sample size.

p

allele frequency used to condition the prior upon.

k

number of grid points for the alleles frequencies at which the prior is evaluated.

Author

Sergio Venturini sergio.venturini@unicatt.it

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

See Also

ip.2, plot-methods.

Examples

Run this code
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #

### The following code reproduces Figure 1 in Consonni et al. (2011) ###
p <- 0.5
t <- 5
cip.2(t, p, 30)
t <- 30
cip.2(t, p, 50)
}

Run the code above in your browser using DataLab