Learn R Programming

HWEintrinsic (version 1.2.3)

cip.tmp: Utility Function

Description

This function provides the calculations needed to plot the conditional intrinsic prior based for a two alleles dataset as described in Consonni et al. (2011).

Usage

cip.tmp(p11, p21, t, p)

Value

cip.tmp returns the value of the conditional intrinsic prior evaluated at the arguments values.

Arguments

p11

gentotype proportion for the alleles pair \(A_{1}A_{1}\).

p21

gentotype proportion for the alleles pair \(A_{2}A_{1}\).

t

training sample size.

p

allele frequency used to condition the prior upon.

Author

Sergio Venturini sergio.venturini@unicatt.it

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

See Also

cip.2, plot-methods.