Learn R Programming

HWEintrinsic (version 1.2.3)

hwe.bf: Standard Bayes Factor for the Hardy-Weinebrg Testing Problem

Description

This function provides the calculations for obtaining the standard Bayes factor for the Hardy-Weinberg testing problem. It implements a common default prior (constant) for both the null and the alternative models.

Usage

hwe.bf(y)

Value

hwe.bf returns the standard Bayes Factor value for the Hardy-Weinberg testing problem (see the references for the details).

Arguments

y

an object of class "HWEdata".

Author

Sergio Venturini sergio.venturini@unicatt.it

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

See Also

hwe.ibf, hwe.ibf.mc, hwe.ibf.plot.

Examples

Run this code
# Example 1 #
data(GuoThompson8)
plot(GuoThompson8)
hwe.bf(GuoThompson8)

# Example 2 #
data(LouisDempster)
plot(LouisDempster)
hwe.bf(LouisDempster)

Run the code above in your browser using DataLab