Learn R Programming

HWEintrinsic (version 1.2.3)

hwe.ibf.mc: Testing Hardy-Weinberg Equilibrium Using an Intrinsic Prior Approach

Description

This function implements the Monte Carlo estimation of the Bayes factor based on intrinsic priors for the Hardy-Weinberg testing problem as described in Consonni et al. (2011).

Usage

hwe.ibf.mc(y, t, M = 10000, verbose = TRUE)

Value

hwe.ibf.mc returns an object of the class "HWEintr".

Arguments

y

an object of class "HWEdata".

t

training sample size.

M

number of Monte Carlo iterations.

verbose

logical; if TRUE the function prints the detailed calculation progress.

Author

Sergio Venturini sergio.venturini@unicatt.it

Details

This function implements a Monte Carlo approximation using importance sampling of the Bayes factor based on intrinsic priors.

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

See Also

hwe.ibf, hwe.ibf.plot.

Examples

Run this code
# Example 1 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #


data(GuoThompson9)
plot(GuoThompson9)
n <- sum(GuoThompson9@data.vec, na.rm = TRUE)
out <- hwe.ibf.mc(GuoThompson9, t = n/2, M = 100000, verbose = TRUE)
summary(out, plot = TRUE)
}

# Example 2 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #

M <- 300000
f <- seq(.1, 1, .05)
n <- sum(GuoThompson9@data.vec, na.rm = TRUE)
out <- hwe.ibf.plot(y = GuoThompson9, t.vec = round(f*n), M = M)
}

Run the code above in your browser using DataLab