Learn R Programming

HWEintrinsic (version 1.2.3)

ip.2: Graph of the (Unconditional) Intrinsic Prior for a Two Alleles Dataset

Description

This function produces the 3D-plot for the (unconditional) intrinsic prior based on a sample of two alleles data as described in Consonni et al. (2011).

Usage

ip.2(t, k = 30)

Value

No object is returned by this function.

Arguments

t

training sample size.

k

number of grid points for the alleles frequencies at which the prior is evaluated.

Author

Sergio Venturini sergio.venturini@unicatt.it

References

Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract

See Also

cip.2, plot-methods.

Examples

Run this code
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #

### The following code reproduces Figure 3 in Consonni et al. (2011) ###
t <- 30
ip.2(t, 40)
}

Run the code above in your browser using DataLab