# Example 1 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #
data(GuoThompson9)
plot(GuoThompson9)
n <- sum(GuoThompson9@data.vec, na.rm = TRUE)
out <- hwe.ibf.mc(GuoThompson9, t = n/2, M = 100000, verbose = TRUE)
summary(out, plot = TRUE)
}
# Example 2 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #
M <- 300000
f <- seq(.1, 1, .05)
n <- sum(GuoThompson9@data.vec, na.rm = TRUE)
out <- hwe.ibf.plot(y = GuoThompson9, t.vec = round(f*n), M = M)
}
Run the code above in your browser using DataLab