# Example 1 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #
data(Wordsworth)
plot(Wordsworth)
n <- sum(Wordsworth@data.vec, na.rm = TRUE)
out <- hwe.ibf.mc(Wordsworth, t = n/2, M = 100000, verbose = TRUE)
summary(out, plot = TRUE)
}
# Example 2 #
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #
data(Wordsworth)
n <- sum(Wordsworth@data.vec, na.rm = TRUE)
M <- 300000
f <- seq(.1, 1, .05)
out <- hwe.ibf.plot(y = Wordsworth, t.vec = round(f*n), M = M)
}
Run the code above in your browser using DataLab