This function provides the calculations needed to plot the conditional intrinsic prior based for a two alleles dataset as described in Consonni et al. (2011).
cip.tmp(p11, p21, t, p)cip.tmp returns the value of the conditional intrinsic prior evaluated at the arguments values.
gentotype proportion for the alleles pair \(A_{1}A_{1}\).
gentotype proportion for the alleles pair \(A_{2}A_{1}\).
training sample size.
allele frequency used to condition the prior upon.
Sergio Venturini sergio.venturini@unicatt.it
Consonni, G., Moreno, E., and Venturini, S. (2011). "Testing Hardy-Weinberg equilibrium: an objective Bayesian analysis". Statistics in Medicine, 30, 62--74. https://onlinelibrary.wiley.com/doi/10.1002/sim.4084/abstract
cip.2,
plot-methods.