hwe.bf: Standard Bayes Factor for the Hardy-Weinebrg Testing Problem
Description
This function provides the calculations for obtaining the standard Bayes factor for the Hardy-Weinberg testing problem. It implements a common default prior (constant) for both the null and the alternative models.
Usage
hwe.bf(y)
Value
hwe.bf returns the standard Bayes Factor value for the Hardy-Weinberg testing problem (see the references for the details).