ip.2: Graph of the (Unconditional) Intrinsic Prior for a Two Alleles Dataset
Description
This function produces the 3D-plot for the (unconditional) intrinsic prior based on a sample of two alleles data as described in Consonni et al. (2011).
Usage
ip.2(t, k = 30)
Value
No object is returned by this function.
Arguments
t
training sample size.
k
number of grid points for the alleles frequencies at which the prior is evaluated.
if (FALSE) {
# ATTENTION: the following code may take a long time to run! #### The following code reproduces Figure 3 in Consonni et al. (2011) ###t <- 30
ip.2(t, 40)
}